;*******************module ab.inc******************************
;
; Ab Base Protocol definitions
;   Environment:  83C751 Assembler
;
;************************************************
; ACCESS.bus Technology Transfer Agreement
; 
; Grant of Right to Use ACCESS.bus Technology
; 
; In exchange for your agreeing to the warranty disclaimer and liability
; limitation stipulated in this Technology Transfer Agreement, Digital
; Equipment Corporation (Digital) grants at no cost to you a royalty-free
; nonexclusive license to use ACCESS.bus technology (as specified in the
; ACCESS.bus Hardware and Protocol Specifications) to design and develop
; any kind of option board, computer system, or application-specific
; integrated circuit (ASIC).  This Agreement does not grant you any other
; rights in Digital's patents, copyrights, trade secrets, trademarks, or
; licenses to ACCESS.bus technology.
; 
; Warranty Disclaimer
; 
; The ACCESS.bus technology is transferred "as is."  Digital
; expressly disclaims all implied warranties including, but not
; limited to, the implied warranties of merchantability and fitness
; for a particular purpose.  Digital does not warrant, guarantee, or
; make any representations regarding the use of or the results of the
; use of source code and related documents in terms of correctness,
; accuracy, or reliability.  Digital believes the code is accurate;
; however, you must assume the risk as to the results and performance
; of any product you develop that is based on the ACCESS.bus technology.
; 
; Limits of Liability
; 
; You agree that Digital shall not be liable to you under this Agreement for
; any damages, including without limitation any lost profits or lost savings,
; or any consequential, incidental, or punitive damages arising out of the use
; or inability to use the ACCESS.bus Keyboard Device source code and related
; documents, or for any claim by another party.  Your exclusive remedy under
; this Agreement shall be the furnishing by Digital of the technical support
; provided herein.  You agree to hold Digital harmless for all claims and
; damages arising from any third party as a result of their use of or inability
; to use any product you develop based on ACCESS.bus technology.
;**************************************************************************
;
;   Date        Revision        Perpetrator
;
;   04-Sep-91   ----            Mark Shepard
;       Changed I_MsgCheck to I_Error, kept I_MsgCheck for backpatibility.
;       Added App_Error (0xb4 to coorespond to I_Error).
;       Changed Sig_Attn from 0 to 3 to make KB code easier.
;
;   04-Aug-91   ----            Mark Shepard
;       Renamed to generic "ab.inc"
;       Added defines for header structure (mainly for documentation purposes).
;       Added defines for bus signal codes (RESET, HALT, ATTN, etc.)
;
;   22-May-91   X0.2            Peter Sichel
;       Added Vendor command codes, and I_MsgCheck.
;
;   30-Jan-91   X0.1            Mark Shepard
;       Created from ODB base protocol spec, X0.7.
;
 
$EJ
;***************
;  Desktop bus command codes for all Interface-part and Application-part
;  commands in the Base Protocol spec.
;
;  Naming Convention -
;    Interface-Part codes are prefixed with "I_",
;    Application-Part with "App_".  Codes specific to a particular
;    sub-protocol (e.g. Keyboard Protocol) could be prefixed with
;    "Key_", "Kb_", or "Kbp_".
;
;    Definitions for sub-protocols should go in separate include files.
;    (keyp.inc, locp.inc, textp.inc, etc.).
;
I_NoMsg         EQU     000h    ; special value, means not a valid message
 
I_Reset         EQU     0f0h    ; reset device
I_IdReq         EQU     0f1h    ; Identify request
I_AsgnAdr       EQU     0f2h    ; assign address
I_CapReq        EQU     0f3h    ; capabilities (fragment) request
 
I_Attn          EQU     0e0h    ; power-on/reset attention
I_IdReply       EQU     0e1h    ; identify reply
I_CapReply      EQU     0e3h    ; capabilities (fragment) reply
I_Error         EQU     0e4h    ; (the future) interface/bus std error report
I_MsgCheck      EQU     0e4h    ; *** obsolete, don't use in new code ***

I_Vendor0       EQU     0c0h    ; vendor reserved command
I_Vendor1       EQU     0c1h    ; vendor reserved command
I_Vendor2       EQU     0c2h    ; vendor reserved command
I_Vendor3       EQU     0c3h    ; vendor reserved command
 
App_Sig         EQU     0a0h    ; hardware signal
App_TestReply   EQU     0a1h    ; test reply (for a specific application-part)
 
App_Test        EQU     0b1h    ; self-test result request
App_Error       EQU     0b4h    ; (the future) std application error report

;***************
;  Well-known I2C addresses used by desktop bus peers
;
; I2C Address Allocation
; row        column
; A6,A5,A4 / A3,A2,A1,A0             R/W=0 (write)
; Host: 2/8                          50h
; Devices: 2/9-2/15, 3/0-3/7         52-6Eh (even numbers only)
; Device default: 3/7                6Eh
 
Adr_Host        EQU     050h    ; standard Host address
Adr_Default     EQU     06eh    ; default (pwr-up) address for peripherals
 
;**************
;  Bus-Signal codes defined at the Base Protocol level
;
Sig_Reset       EQU     1       ; hardware reset!
Sig_Halt        EQU     2       ; debugging interrupt
Sig_Attn        EQU     3       ; general-purpose interrupt from User

;**************
;  Defines related to message structure
;
;  Declarations prefixed with "AbWire_" refer to Ab objects, fields, etc.
;  as transmitted across the i2c "wire" (as opposed to the "optimized frame
;  format used between the host and 83c751 host-ctrlr).
;
;
AbWire_HdrSiz   EQU     3       ; Ab Header Size on the wire:  dst + src + PLen
AbWire_LenMask  EQU     7fh     ; Ab mask for length field
AbWire_MaxLen   EQU     127     ; Ab maximum data bytes in message

;*************** End of include file
